@@ -6,18 +6,18 @@ module type S = sig
       The [salt] must be eight octets, [count] the iteration count.
       @raise Invalid_argument when either [salt] is not eight octets long or either
       [count] or [dk_len] are not valid. *)
-  val pbkdf1 : password:Cstruct.t -> salt:Cstruct.t -> count:int -> dk_len:int -> Cstruct.t
+  val pbkdf1 : password:string -> salt:string -> count:int -> dk_len:int -> string
 
   (** [pbkdf2 password salt count dk_len] is [dk], the derived key of [dk_len] octets.
       @raise Invalid_argument when either [count] or [dk_len] are not valid *)
-  val pbkdf2 : password:Cstruct.t -> salt:Cstruct.t -> count:int -> dk_len:int32 -> Cstruct.t
+  val pbkdf2 : password:string -> salt:string -> count:int -> dk_len:int32 -> string
 end
 
 (** Given a Hash/pseudorandom function, get the PBKDF *)
-module Make (H: Mirage_crypto.Hash.S) : S
+module Make (H: Digestif.S) : S
 
 (** convenience [pbkdf1 hash password salt count dk_len] where the [hash] has to be provided explicitly *)
-val pbkdf1 : hash:[`MD5 | `SHA1] -> password:Cstruct.t -> salt:Cstruct.t -> count:int -> dk_len:int -> Cstruct.t
+val pbkdf1 : hash:Digestif.hash'  -> password:string -> salt:string -> count:int -> dk_len:int -> string
 
 (** convenience [pbkdf2 prf password salt count dk_len] where the [prf] has to be provided explicitly *)
-val pbkdf2 : prf:Mirage_crypto.Hash.hash -> password:Cstruct.t -> salt:Cstruct.t -> count:int -> dk_len:int32 -> Cstruct.t
+val pbkdf2 : prf:Digestif.hash' -> password:string -> salt:string -> count:int -> dk_len:int32 -> string
